@@ -22,12 +22,7 @@
 
 #include "databasetestdata.h"
 
-#include "musicaudiotrack.h"
-
-#include <QList>
 #include <QHash>
-#include <QString>
-#include <QUrl>
 
 class ManageHeaderBarTest : public QObject, public DatabaseTestData
 {
@@ -40,8 +35,7 @@ public:
         IsValidRole = Qt::UserRole + 1,
         TitleRole = IsValidRole + 1,
         DurationRole = TitleRole + 1,
-        MilliSecondsDurationRole = DurationRole + 1,
-        CreatorRole = MilliSecondsDurationRole + 1,
+        CreatorRole = DurationRole + 1,
         ArtistRole = CreatorRole + 1,
         AlbumRole = ArtistRole + 1,
         TrackNumberRole = AlbumRole + 1,
@@ -65,25 +59,9 @@ private Q_SLOTS:
 
     void simpleInitialCase();
 
-    void setCurrentTrackCase();
+    void setCurrentTrackWithInvalidData();
 
-    void setCurrentTrackCaseFromNewAlbum();
-
-    void completeCase();
-
-    void setCurrentTrackAndInvalidCase();
-
-    void setCurrentTrackAndRemoveItCase();
-
-    void insertBeforeCurrentTrack();
-
-    void moveCurrentTrack();
-
-    void moveAnotherTrack();
-
-    void setCurrentTrackTest();
-
-    void setPlayListModelTest();
+    void setCurrentTrackWithData();
 
 };
 
